Struct Keyboard

pub struct Keyboard<'a> { /* private fields */ }
A struct for controlling a virtual keyboard.

It holds a reference to a Device which is used to send the keyboard commands.

Implementations

Source

impl<'a> Keyboard<'a>

pub const fn new(device: &'a Device) -> Self

Creates a new Keyboard.

pub fn press(&self, button: Key)

Presses a single keyboard button.

The button is held down until a release() or multi_press() with Key::NONE is called.

Arguments
  • button - The Key to press.
pub fn release(&self)

Releases all currently pressed keyboard buttons.

This effectively sends a “no keys pressed” command to the device.

pub fn press_and_release(&self, button: Key, millis: u64)

Presses and releases a single keyboard button.

The button is pressed down, held for the specified duration, then released.

Arguments
  • button - The Key to press and release.
  • millis - The duration in milliseconds to hold the button down before releasing it.
pub fn multi_press( &self, button1: Key, button2: Key, button3: Key, button4: Key, button5: Key, button6: Key, )

Presses up to six keyboard buttons simultaneously.

This can be used for pressing modifier keys and other keys at the same time.

Arguments
  • button1 - The first Key to press.
  • button2 - The second Key to press.
  • button3 - The third Key to press.
  • button4 - The fourth Key to press.
  • button5 - The fifth Key to press.
  • button6 - The sixth Key to press.
pub fn type_string(&self, string: &str, millis: u64) -> Result<(), String>

Types a string by simulating individual key presses for each character.

Arguments
  • string - The string to be typed.
  • millis - The duration in milliseconds to hold the button down before releasing it.
Errors

This function will return an error if a character in the input string cannot be converted into a valid Key enum variant.